Module subplot_grid

Module subplot_grid 

Structs

SubplotGrid
A structure representing a subplot grid layout.
SubplotGridIrregularBuilder
Use builder syntax to set the inputs and finish with build().
SubplotGridRegularBuilder
Use builder syntax to set the inputs and finish with build().